@@ -2,38 +2,40 @@ from .. import usbhid
 
 
 profile = {
-
     "name": "SteelSeries Rival 100 / SteelSeries Rival 105",
-
-    "models": [{
-        "name": "SteelSeries Rival 100",
-        "vendor_id": 0x1038,
-        "product_id": 0x1702,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Rival 100 (Dell China)",
-        "vendor_id": 0x1038,
-        "product_id": 0x170a,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Rival 100 Dota 2 Edition (retail)",
-        "vendor_id": 0x1038,
-        "product_id": 0x170b,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Rival 100 Dota 2 Edition (Lenovo)",
-        "vendor_id": 0x1038,
-        "product_id": 0x170c,
-        "endpoint": 0,
-    }, {
-        "name": "SteelSeries Rival 105",
-        "vendor_id": 0x1038,
-        "product_id": 0x1814,
-        "endpoint": 0,
-    }],
-
+    "models": [
+        {
+            "name": "SteelSeries Rival 100",
+            "vendor_id": 0x1038,
+            "product_id": 0x1702,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Rival 100 (Dell China)",
+            "vendor_id": 0x1038,
+            "product_id": 0x170A,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Rival 100 Dota 2 Edition (retail)",
+            "vendor_id": 0x1038,
+            "product_id": 0x170B,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Rival 100 Dota 2 Edition (Lenovo)",
+            "vendor_id": 0x1038,
+            "product_id": 0x170C,
+            "endpoint": 0,
+        },
+        {
+            "name": "SteelSeries Rival 105",
+            "vendor_id": 0x1038,
+            "product_id": 0x1814,
+            "endpoint": 0,
+        },
+    ],
     "settings": {
-
         "sensitivity1": {
             "label": "Sensibility preset 1",
             "description": "Set sensitivity preset 1 (DPI)",
@@ -53,7 +55,6 @@ profile = {
             },
             "default": 1000,
         },
-
         "sensitivity2": {
             "label": "Sensibility preset 2",
             "description": "Set sensitivity preset 2 (DPI)",
@@ -73,7 +74,6 @@ profile = {
             },
             "default": 2000,
         },
-
         "polling_rate": {
             "label": "Polling rate",
             "description": "Set polling rate (Hz)",
@@ -89,7 +89,6 @@ profile = {
             },
             "default": 1000,
         },
-
         "color": {
             "label": "LED color",
             "description": "Set the mouse LED color",
@@ -97,9 +96,8 @@ profile = {
             "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
             "command": [0x05, 0x00],
             "value_type": "rgbcolor",
-            "default": "#FF1800"
+            "default": "#FF1800",
         },
-
         "light_effect": {
             "label": "Light effect",
             "description": "Set the light effect",
@@ -117,7 +115,6 @@ profile = {
             },
             "default": "steady",
         },
-
         "btn6_mode": {
             "label": "Button 6 mode",
             "description": "Set the mode of the button under the wheel",
@@ -131,12 +128,9 @@ profile = {
             },
             "default": "dpi",
         },
-
     },
-
     "save_command": {
         "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
         "command": [0x09, 0x00],
     },
-
 }
