@@ -2,23 +2,22 @@ from .. import usbhid
 
 
 profile = {
-
     "name": "SteelSeries Rival 3",
-
-    "models": [{
-        "name": "SteelSeries Rival 3",
-        "vendor_id": 0x1038,
-        "product_id": 0x1824,
-        "endpoint": 3,
-    }, {
-        "name": "SteelSeries Rival 3 (firmware v0.37.0.0)",
-        "vendor_id": 0x1038,
-        "product_id": 0x184c,
-        "endpoint": 3,
-    }],
-
+    "models": [
+        {
+            "name": "SteelSeries Rival 3",
+            "vendor_id": 0x1038,
+            "product_id": 0x1824,
+            "endpoint": 3,
+        },
+        {
+            "name": "SteelSeries Rival 3 (firmware v0.37.0.0)",
+            "vendor_id": 0x1038,
+            "product_id": 0x184C,
+            "endpoint": 3,
+        },
+    ],
     "settings": {
-
         "sensitivity": {
             "label": "Sensibility presets",
             "description": "Set sensitivity preset (DPI)",
@@ -29,11 +28,11 @@ profile = {
             "input_range": [200, 8500, 100],
             "output_range": [4, 0xC5, 2.33],
             "dpi_length_byte": 1,
+            "first_preset": 1,
             "count_mode": "number",
             "max_preset_count": 5,
             "default": "800, 1600",
         },
-
         "polling_rate": {
             "label": "Polling rate",
             "description": "Set polling rate (Hz)",
@@ -49,7 +48,6 @@ profile = {
             },
             "default": 1000,
         },
-
         # 0x05 0x00 <LED_ID> <R> <G> <B> <BRIGHTNESS>
         # LED_ID: 0x00 all
         #         0x01 zone 1 (top)
@@ -65,9 +63,8 @@ profile = {
             "command": [0x05, 0x00, 0x01],
             "command_suffix": [0x64],
             "value_type": "rgbcolor",
-            "default": "red"
+            "default": "red",
         },
-
         "z2_color": {
             "label": "Strip middle LED color",
             "description": "Set the color of the middle LED of the strip",
@@ -76,9 +73,8 @@ profile = {
             "command": [0x05, 0x00, 0x02],
             "command_suffix": [0x64],
             "value_type": "rgbcolor",
-            "default": "lime"
+            "default": "lime",
         },
-
         "z3_color": {
             "label": "Strip bottom LED color",
             "description": "Set the color of the bottom LED of the strip",
@@ -87,9 +83,8 @@ profile = {
             "command": [0x05, 0x00, 0x03],
             "command_suffix": [0x64],
             "value_type": "rgbcolor",
-            "default": "blue"
+            "default": "blue",
         },
-
         "logo_color": {
             "label": "Logo LED color",
             "description": "Set the color of the logo LED",
@@ -98,9 +93,8 @@ profile = {
             "command": [0x05, 0x00, 0x04],
             "command_suffix": [0x64],
             "value_type": "rgbcolor",
-            "default": "purple"
+            "default": "purple",
         },
-
         "light_effect": {
             "label": "Light effect",
             "description": "Set the light effect",
@@ -119,7 +113,6 @@ profile = {
             },
             "default": "steady",
         },
-
         "buttons_mapping": {
             "label": "Buttons mapping",
             "description": "Set the mapping of the buttons",
@@ -127,41 +120,35 @@ profile = {
             "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
             "command": [0x07, 0x00],
             "value_type": "buttons",
-
+            # fmt: off
             "buttons": {
-                "Button1": {"id": 0x01, "offset": 0x00, "default": "button1"},
-                "Button2": {"id": 0x02, "offset": 0x02, "default": "button2"},
-                "Button3": {"id": 0x03, "offset": 0x04, "default": "button3"},
-                "Button4": {"id": 0x04, "offset": 0x06, "default": "button4"},
-                "Button5": {"id": 0x05, "offset": 0x08, "default": "button5"},
-                "Button6": {"id": 0x06, "offset": 0x0A, "default": "dpi"},
-                "ScrollUp": {"id": 0x31, "offset": 0x0C, "default": "scrollup"},  # noqa
-                "ScrollDown": {"id": 0x32, "offset": 0x0E, "default": "scrolldown"},  # noqa
+                "Button1":    {"id": 0x01, "offset": 0x00, "default": "button1"},
+                "Button2":    {"id": 0x02, "offset": 0x02, "default": "button2"},
+                "Button3":    {"id": 0x03, "offset": 0x04, "default": "button3"},
+                "Button4":    {"id": 0x04, "offset": 0x06, "default": "button4"},
+                "Button5":    {"id": 0x05, "offset": 0x08, "default": "button5"},
+                "Button6":    {"id": 0x06, "offset": 0x0A, "default": "dpi"},
+                "ScrollUp":   {"id": 0x31, "offset": 0x0C, "default": "scrollup"},
+                "ScrollDown": {"id": 0x32, "offset": 0x0E, "default": "scrolldown"},
             },
-
-            "button_field_length": 2,
-
             "button_disable":     0x00,
             "button_dpi_switch":  0x30,
             "button_scroll_up":   0x31,
             "button_scroll_down": 0x32,
             "button_keyboard":    0x33,
             "button_multimedia":  0x34,
-
-            "default": "buttons(button1=button1; button2=button2; button3=button3; button4=button4; button5=button5; button6=dpi; scrollup=scrollup; scrolldown=scrolldown; layout=qwerty)",  # noqa
+            # fmt: on
+            "button_field_length": 2,
+            "default": "buttons(button1=button1; button2=button2; button3=button3; button4=button4; button5=button5; button6=dpi; scrollup=scrollup; scrolldown=scrolldown; layout=qwerty)",
         },
-
     },
-
     "save_command": {
         "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
         "command": [0x09, 0x00],
     },
-
     "firmware_version": {
         "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
         "command": [0x10, 0x00],
         "response_length": 2,
     },
-
 }
