@@ -1,6 +1,7 @@
 from .. import usbhid
 
 
+# fmt: off
 _RGBGRADIENT_HEADER = {
     "header_length": 26,       # Length of the header excuding command / LED ID
     "led_id_offsets": [0],     # Offset of the "led_id" fields
@@ -10,23 +11,24 @@ _RGBGRADIENT_HEADER = {
     "triggers_offset": 21,     # Offset of the "triggers" field (buttons mask)
     "color_count_offset": 25,  # Offset of the "color_count" field
 }
+# fmt: on
 
-_DEFAULT_RGBGRADIENT = "rgbgradient(duration=1000; colors=0%: #ff0000, 33%: #00ff00, 66%: #0000ff)"  # noqa
+_DEFAULT_RGBGRADIENT = (
+    "rgbgradient(duration=1000; colors=0%: #ff0000, 33%: #00ff00, 66%: #0000ff)"
+)
 
 
 profile = {
-
     "name": "SteelSeries Sensei 310",
-
-    "models": [{
-        "name": "SteelSeries Sensei 310",
-        "vendor_id": 0x1038,
-        "product_id": 0x1722,
-        "endpoint": 0,
-    }],
-
+    "models": [
+        {
+            "name": "SteelSeries Sensei 310",
+            "vendor_id": 0x1038,
+            "product_id": 0x1722,
+            "endpoint": 0,
+        }
+    ],
     "settings": {
-
         "sensitivity1": {
             "label": "Sensitivity preset 1",
             "description": "Set sensitivity preset 1 (DPI)",
@@ -39,7 +41,6 @@ profile = {
             "output_range": [0x00, 0x77, 1],
             "default": 800,
         },
-
         "sensitivity2": {
             "label": "Sensitivity preset 2",
             "description": "Set sensitivity preset 2 (DPI)",
@@ -52,7 +53,6 @@ profile = {
             "output_range": [0x00, 0x77, 1],
             "default": 1600,
         },
-
         "polling_rate": {
             "label": "Polling rate",
             "description": "Set polling rate (Hz)",
@@ -68,7 +68,6 @@ profile = {
             },
             "default": 1000,
         },
-
         "logo_color": {
             "label": "Logo LED colors and effects",
             "description": "Set the colors and the effects of the logo LED",
@@ -80,7 +79,6 @@ profile = {
             "led_id": 0x00,
             "default": _DEFAULT_RGBGRADIENT,
         },
-
         "wheel_color": {
             "label": "Wheel LED colors and effects",
             "description": "Set the colors and the effects of the wheel LED",
@@ -92,7 +90,6 @@ profile = {
             "led_id": 0x01,
             "default": _DEFAULT_RGBGRADIENT,
         },
-
         "buttons_mapping": {
             "label": "Buttons mapping",
             "description": "Set the mapping of the buttons",
@@ -100,7 +97,6 @@ profile = {
             "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
             "command": [0x31, 0x00],
             "value_type": "buttons",
-
             "buttons": {
                 "Button1": {"id": 0x01, "offset": 0x00, "default": "button1"},
                 "Button2": {"id": 0x02, "offset": 0x05, "default": "button2"},
@@ -111,30 +107,25 @@ profile = {
                 "Button7": {"id": 0x07, "offset": 0x1E, "default": "PageUp"},
                 "Button8": {"id": 0x08, "offset": 0x23, "default": "dpi"},
             },
-
-            "button_field_length": 5,
-
+            # fmt: off
             "button_disable":     0x00,
             "button_keyboard":    0x51,
             "button_multimedia":  0x61,
             "button_dpi_switch":  0x30,
             "button_scroll_up":   0x31,
             "button_scroll_down": 0x32,
-
-            "default": "buttons(button1=button1; button2=button2; button3=button3; button4=button4; button5=button5; button6=PageDown; button7=PageUp; button8=dpi; layout=qwerty)",  # noqa
+            # fmt: on
+            "button_field_length": 5,
+            "default": "buttons(button1=button1; button2=button2; button3=button3; button4=button4; button5=button5; button6=PageDown; button7=PageUp; button8=dpi; layout=qwerty)",
         },
-
     },
-
     "save_command": {
         "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
         "command": [0x59, 0x00],
     },
-
     "firmware_version": {
         "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
         "command": [0x90, 0x00],
         "response_length": 2,
     },
-
 }
